@@ -5,7 +5,7 @@ from typing import Dict
 from py_dot.core.dicts import merge
 
 
-def load(json_filename: str, extends_property: str = 'extends') -> Dict:
+def load(json_filename: str, extends_property: str = 'extends', snake_case=False) -> Dict:
     """ json.loads with assign `extends` file as source
 
     """
@@ -20,7 +20,12 @@ def load(json_filename: str, extends_property: str = 'extends') -> Dict:
     extends_length = len(extends_values) - 1
     while extends_length > 0:
         previous_index = extends_length - 1
-        extends_values[previous_index] = merge(extends_values[extends_length], extends_values[previous_index], False)
+        extends_values[previous_index] = merge(
+            extends_values[extends_length],
+            extends_values[previous_index],
+            False,
+            snake_case
+        )
         extends_length -= 1
 
     return extends_values[0]
